@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * brasero
- * Copyright (C) Philippe Rouquier 2007 <bonfire-app@wanadoo.fr>
+ * Copyright (C) Philippe Rouquier 2007-2008 <bonfire-app@wanadoo.fr>
  * 
  * brasero is free software.
  * 
@@ -10,13 +10,13 @@
  * Foundation; either version 2 of the License, or (at your option)
  * any later version.
  * 
- * trunk is distributed in the hope that it will be useful,
+ * brasero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with trunk.  If not, write to:
+ * along with brasero.  If not, write to:
  * 	The Free Software Foundation, Inc.,
  * 	51 Franklin Street, Fifth Floor
  * 	Boston, MA  02110-1301, USA.
@@ -414,9 +414,9 @@ brasero_data_project_node_to_uri (BraseroDataProject *self,
 				  BraseroFileNode *node)
 {
 	BraseroDataProjectPrivate *priv;
+	GSList *list = NULL;
 	gchar *retval;
 	guint uri_len;
-	GSList *list;
 	GSList *iter;
 	gchar *ptr;
 	guint len;
@@ -433,20 +433,26 @@ brasero_data_project_node_to_uri (BraseroDataProject *self,
 	uri_len = 0;
 	list = NULL;
 	for (; node; node = node->parent) {
+		gchar *escaped_name;
+
 		if (node->is_grafted)
 			break;
 
 		if (node == priv->root)
 			break;
 
-		list = g_slist_prepend (list, node);
-
 		/* the + 1 is for the separator */
-		uri_len += strlen (BRASERO_FILE_NODE_NAME (node)) + 1;
+		escaped_name = g_uri_escape_string (BRASERO_FILE_NODE_NAME (node), NULL, TRUE);
+		uri_len += strlen (escaped_name) + 1;
+		list = g_slist_prepend (list, escaped_name);
 	}
 
-	if (!node || node->is_root)
+	/* The node here is the first grafted parent */
+	if (!node || node->is_root) {
+		g_slist_foreach (list, (GFunc) g_free, NULL);
+		g_slist_free (list);
 		return NULL;
+	}
 
 	/* NOTE: directories URIs shouldn't have a separator at end */
 	len = strlen (BRASERO_FILE_NODE_GRAFT (node)->node->uri);
@@ -458,19 +464,21 @@ brasero_data_project_node_to_uri (BraseroDataProject *self,
 	ptr = retval + len;
 
 	for (iter = list; iter; iter = iter->next) {
-		node = iter->data;
+		gchar *escaped_name;
+
+		escaped_name = iter->data;
 
 		ptr [0] = G_DIR_SEPARATOR;
 		ptr ++;
 
-		len = strlen (BRASERO_FILE_NODE_NAME (node));
-		memcpy (ptr, BRASERO_FILE_NODE_NAME (node), len);
+		len = strlen (escaped_name);
+		memcpy (ptr, escaped_name, len);
 		ptr += len;
 	}
+	g_slist_foreach (list, (GFunc) g_free, NULL);
 	g_slist_free (list);
 
 	ptr [0] = '\0';
-
 	return retval;
 }
 			  
@@ -1358,7 +1366,7 @@ brasero_data_project_rename_node (BraseroDataProject *self,
 	 * simply not possible to rename. */
 	sibling = brasero_file_node_check_name_existence (node->parent, name);
 	if (sibling) {
-		if (brasero_data_project_file_signal (self, NAME_COLLISION_SIGNAL, BRASERO_FILE_NODE_NAME (node)))
+		if (brasero_data_project_file_signal (self, NAME_COLLISION_SIGNAL, name))
 			return FALSE;
 
 		if (sibling != node)
@@ -2300,9 +2308,9 @@ brasero_data_project_is_video_project (BraseroDataProject *self)
 
 		if (!strcmp (name, "VIDEO_TS")) {
 			BraseroFileNode *child;
-			gboolean has_ifo, has_vob, has_bup;
+			gboolean has_ifo, has_bup;
 
-			has_ifo = has_vob = has_bup = FALSE;
+			has_ifo = has_bup = FALSE;
 			child = BRASERO_FILE_NODE_CHILDREN (iter);
 
 			for (; child; child = child->next) {
@@ -2312,13 +2320,11 @@ brasero_data_project_is_video_project (BraseroDataProject *self)
 
 				if (!strcmp (name, "VIDEO_TS.IFO"))
 					has_ifo = TRUE;
-				else if (!strcmp (name, "VIDEO_TS.VOB"))
-					has_vob = TRUE;
 				else if (!strcmp (name, "VIDEO_TS.BUP"))
 					has_bup = TRUE;
 			}
 
-			if (!has_ifo || !has_vob || !has_bup)
+			if (!has_ifo || !has_bup)
 				return FALSE;
 
 			has_video = TRUE;
@@ -3312,7 +3318,7 @@ brasero_data_project_file_removed (BraseroFileMonitor *monitor,
 	g_free (uri);
 
 	/* check if we can remove it (no more nodes) */
-	if (uri_node->nodes)
+	if (!uri_node || uri_node->nodes)
 		return;
 
 	g_hash_table_remove (priv->grafts, uri_node->uri);
