@@ -1,22 +1,22 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
- * trunk
- * Copyright (C) Philippe Rouquier 2007 <bonfire-app@wanadoo.fr>
+ * brasero
+ * Copyright (C) Philippe Rouquier 2007-2008 <bonfire-app@wanadoo.fr>
  * 
- * trunk is free software.
+ * brasero is free software.
  * 
  * You may redistribute it and/or modify it under the terms of the
  * GNU General Public License, as published by the Free Software
  * Foundation; either version 2 of the License, or (at your option)
  * any later version.
  * 
- * trunk is distributed in the hope that it will be useful,
+ * brasero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with trunk.  If not, write to:
+ * along with brasero.  If not, write to:
  * 	The Free Software Foundation, Inc.,
  * 	51 Franklin Street, Fifth Floor
  * 	Boston, MA  02110-1301, USA.
@@ -460,21 +460,7 @@ brasero_data_tree_model_get_value (GtkTreeModel *model,
 
 	case BRASERO_DATA_TREE_MODEL_NAME:
 		g_value_init (value, G_TYPE_STRING);
-
-		/* we may have to set some markup on it */
-		if (node->is_imported) {
-			gchar *markup;
-
-			/* italics and small difference in colour */
-			markup = g_strdup_printf ("<span foreground='grey50'>%s</span>",
-						  BRASERO_FILE_NODE_NAME (node));
-
-			g_value_set_string (value, markup);
-			g_free (markup);
-		}
-		else
-			g_value_set_string (value, BRASERO_FILE_NODE_NAME (node));
-
+		g_value_set_string (value, BRASERO_FILE_NODE_NAME (node));
 		return;
 
 	case BRASERO_DATA_TREE_MODEL_MIME_DESC:
@@ -622,6 +608,13 @@ brasero_data_tree_model_get_value (GtkTreeModel *model,
 
 		return;
 
+	case BRASERO_DATA_TREE_MODEL_COLOR:
+		g_value_init (value, G_TYPE_STRING);
+		if (node->is_imported)
+			g_value_set_string (value, "grey50");
+
+		return;
+
 	default:
 		return;
 	}
@@ -811,6 +804,9 @@ brasero_data_tree_model_get_column_type (GtkTreeModel *model,
 	case BRASERO_DATA_TREE_MODEL_STYLE:
 		return PANGO_TYPE_STYLE;
 
+	case BRASERO_DATA_TREE_MODEL_COLOR:
+		return G_TYPE_STRING;
+
 	case BRASERO_DATA_TREE_MODEL_EDITABLE:
 		return G_TYPE_BOOLEAN;
 
