@@ -105,7 +105,7 @@ brasero_project_manager_selected_uris_changed (BraseroURIContainer *container,
 
 /* menus */
 static GtkActionEntry entries [] = {
-	{"Cover", NULL, N_("_Cover editor"), NULL,
+	{"Cover", NULL, N_("_Cover Editor"), NULL,
 	 N_("Design and print covers for CDs"), G_CALLBACK (brasero_project_manager_new_cover_cb)},
 	 {"New", GTK_STOCK_NEW, N_("_New Project"), NULL,
 	 N_("Create a new project"), NULL },
@@ -345,7 +345,7 @@ brasero_project_manager_selected_uris_changed (BraseroURIContainer *container,
 					   manager->priv->size_preview);
 
 	uris = brasero_uri_container_get_selected_uris (container);
-    	if (!uris) {
+	if (!uris) {
 		gtk_statusbar_pop (GTK_STATUSBAR (manager->priv->status),
 				   manager->priv->status_ctx);
 		gtk_statusbar_push (GTK_STATUSBAR (manager->priv->status),
@@ -550,7 +550,7 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 		}
 
 		if (toplevel)
-			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New audio disc project"));
+			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New Audio Disc Project"));
 	}
 	else if (type == BRASERO_PROJECT_TYPE_DATA) {
 		brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_DATA);
@@ -564,7 +564,7 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 		}
 
 		if (toplevel)
-			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New data disc project"));
+			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New Data Disc Project"));
 	}
 	else if (type == BRASERO_PROJECT_TYPE_ISO) {
 		brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_NONE);
@@ -574,7 +574,7 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 		gtk_action_set_sensitive (action, FALSE);
 
 		if (toplevel)
-			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New image file"));
+			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New Image File"));
 		brasero_project_manager_burn_iso_dialog (manager, uri);
 	}
 	else if (type == BRASERO_PROJECT_TYPE_COPY) {
@@ -585,7 +585,7 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 		gtk_action_set_sensitive (action, FALSE);
 
 		if (toplevel)
-			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - Copy a disc"));
+			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - Disc Copy"));
 
 		brasero_project_manager_burn_disc (manager);
 	}
@@ -750,6 +750,8 @@ BraseroProjectType
 brasero_project_manager_open_uri (BraseroProjectManager *manager,
 				  const gchar *uri_arg)
 {
+  	GtkWidget *dialog;
+	GtkWidget *window;
 	gchar *uri;
 	GFile *file;
 	GFileInfo *info;
@@ -767,7 +769,21 @@ brasero_project_manager_open_uri (BraseroProjectManager *manager,
 	uri = g_file_get_uri (file);
 	mime = g_file_info_get_content_type (info);
 
-	type = brasero_project_manager_open_by_mime (manager, uri, mime);
+	if (g_file_query_exists (file, NULL)) {
+	  	type = brasero_project_manager_open_by_mime (manager, uri, mime);
+        } 
+	else {
+	  	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+					   	GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					   	GTK_MESSAGE_ERROR,
+					   	GTK_BUTTONS_CLOSE,
+					   	"Error loading project");
+	  	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("The project '%s' does not exist."),
+							  uri);
+	  	gtk_dialog_run (GTK_DIALOG (dialog));
+	  	gtk_widget_destroy (dialog);
+	}
 
 	g_free (uri);
 	g_object_unref (file);
@@ -786,7 +802,7 @@ brasero_project_manager_open_cb (GtkAction *action, BraseroProjectManager *manag
 	BraseroProjectType type;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-	chooser = gtk_file_chooser_dialog_new (_("Open a project"),
+	chooser = gtk_file_chooser_dialog_new (_("Open Project"),
 					      GTK_WINDOW (toplevel),
 					      GTK_FILE_CHOOSER_ACTION_OPEN,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -933,7 +949,7 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 				   chooser,
 				   "Chooser",
 				   _("Browse the file system"),
-				   _("Display file browser"),
+				   _("Display File Browser"),
 				   GTK_STOCK_DIRECTORY,
 				   BRASERO_LAYOUT_AUDIO|BRASERO_LAYOUT_DATA);
 
@@ -957,7 +973,7 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 				   search,
 				   "Search",
 				   _("Search files using keywords"),
-				   _("Display search"),
+				   _("Display Search"),
 				   GTK_STOCK_FIND,
 				   BRASERO_LAYOUT_AUDIO|BRASERO_LAYOUT_DATA);
 
@@ -978,7 +994,7 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 				   playlist,
 				   "Playlist",
 				   _("Display playlists and their contents"),
-				   _("Display playlists"),
+				   _("Display Playlists"),
 				   "audio-x-generic", 
 				   BRASERO_LAYOUT_AUDIO);
 
