@@ -1250,6 +1250,7 @@ brasero_burn_caps_new_task (BraseroBurnCaps *self,
 		/* retry with the same disc type but blank this time */
 		media &= ~(BRASERO_MEDIUM_CLOSED|
 			   BRASERO_MEDIUM_APPENDABLE|
+	   		   BRASERO_MEDIUM_UNFORMATTED|
 			   BRASERO_MEDIUM_HAS_DATA|
 			   BRASERO_MEDIUM_HAS_AUDIO);
 		media |= BRASERO_MEDIUM_BLANK;
@@ -1776,6 +1777,7 @@ brasero_caps_try_output_with_blanking (BraseroBurnCaps *self,
 	media = output->subtype.media;
 	media &= ~(BRASERO_MEDIUM_CLOSED|
 		   BRASERO_MEDIUM_APPENDABLE|
+		   BRASERO_MEDIUM_UNFORMATTED|
 		   BRASERO_MEDIUM_HAS_DATA|
 		   BRASERO_MEDIUM_HAS_AUDIO);
 	media |= BRASERO_MEDIUM_BLANK;
@@ -1876,6 +1878,83 @@ brasero_burn_caps_is_output_supported (BraseroBurnCaps *self,
 	return BRASERO_BURN_OK;
 }
 
+static BraseroBurnResult
+brasero_burn_caps_is_session_supported_same_src_dest (BraseroBurnCaps *self,
+						      BraseroBurnSession *session)
+{
+	GSList *iter;
+	BraseroTrackType input;
+	BraseroTrackType output;
+	BraseroImageFormat format;
+	BraseroBurnFlag session_flags;
+
+	BRASERO_BURN_LOG ("Checking disc copy support with same source and destination");
+
+	/* To determine if a CD/DVD can be copied using the same source/dest,
+	 * we first determine if can be imaged and then if this image can be 
+	 * burnt to whatever medium type. */
+	memset (&input, 0, sizeof (BraseroTrackType));
+	brasero_burn_session_get_input_type (session, &input);
+	BRASERO_BURN_LOG_TYPE (&input, "input");
+
+	/* NOTE: BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE is a problem here since it
+	 * is only used if needed. Likewise DAO can be a problem. So just in
+	 * case remove them. They are not really useful in this context. What we
+	 * want here is to know whether a medium can be used given the input;
+	 * only 1 flag is important here (MERGE) and can have consequences. */
+	session_flags = brasero_burn_session_get_flags (session);
+	session_flags &= ~(BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE|BRASERO_BURN_FLAG_DAO);
+
+	BRASERO_BURN_LOG_FLAGS (session_flags, "flags");
+
+	/* Find one available output format */
+	format = BRASERO_IMAGE_FORMAT_CDRDAO;
+	output.type = BRASERO_TRACK_TYPE_IMAGE;
+
+	for (; format > BRASERO_IMAGE_FORMAT_NONE; format >>= 1) {
+		BraseroBurnResult result;
+
+		output.subtype.img_format = format;
+
+		BRASERO_BURN_LOG_TYPE (&output, "Testing temporary image format");
+		result = brasero_caps_try_output_with_blanking (self,
+								session,
+								&output,
+								&input,
+								BRASERO_PLUGIN_IO_ACCEPT_FILE);
+		if (result != BRASERO_BURN_OK)
+			continue;
+
+		/* This format can be used to create an image. Check if can be
+		 * burnt now. Just find at least one medium. */
+		for (iter = self->priv->caps_list; iter; iter = iter->next) {
+			BraseroCaps *caps;
+			gboolean result;
+
+			caps = iter->data;
+
+			if (caps->type.type != BRASERO_TRACK_TYPE_DISC)
+				continue;
+
+			/* Put BRASERO_MEDIUM_NONE so we can always succeed */
+			result = brasero_caps_find_link (caps,
+							 session_flags,
+							 BRASERO_MEDIUM_NONE,
+							 &input,
+							 BRASERO_PLUGIN_IO_ACCEPT_FILE);
+
+			BRASERO_BURN_LOG_DISC_TYPE (caps->type.subtype.media,
+						    "Tested medium (%s)",
+						    result ? "working":"not working");
+
+			if (result)
+				return BRASERO_BURN_OK;
+		}
+	}
+
+	return BRASERO_BURN_NOT_SUPPORTED;
+}
+
 BraseroBurnResult
 brasero_burn_caps_is_session_supported (BraseroBurnCaps *self,
 					BraseroBurnSession *session)
@@ -1885,6 +1964,10 @@ brasero_burn_caps_is_session_supported (BraseroBurnCaps *self,
 	BraseroTrackType output;
 	BraseroPluginIOFlag io_flags;
 
+	/* Special case */
+	if (brasero_burn_session_same_src_dest_drive (session))
+		return brasero_burn_caps_is_session_supported_same_src_dest (self, session);
+
 	/* Here flags don't matter as we don't record anything.
 	 * Even the IOFlags since that can be checked later with
 	 * brasero_burn_caps_get_flags. */
@@ -1950,8 +2033,7 @@ brasero_burn_caps_get_required_media_type (BraseroBurnCaps *self,
 	 * want here is to know which media can be used given the input; only 1
 	 * flag is important here (MERGE) and can have consequences. */
 	session_flags = brasero_burn_session_get_flags (session);
-	session_flags &= ~(BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE|
-			   BRASERO_BURN_FLAG_DAO);
+	session_flags &= ~(BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE|BRASERO_BURN_FLAG_DAO);
 
 	BRASERO_BURN_LOG_FLAGS (session_flags, "and flags");
 
@@ -2312,7 +2394,7 @@ brasero_burn_caps_get_flags (BraseroBurnCaps *self,
 		 * then write on its own. Basically that works only with
 		 * overwrite formatted discs, DVD+RW, ...) */
 
-		if (!(media & (BRASERO_MEDIUM_HAS_AUDIO|BRASERO_MEDIUM_HAS_DATA))) {
+		if (!(media & (BRASERO_MEDIUM_HAS_AUDIO|BRASERO_MEDIUM_HAS_DATA|BRASERO_MEDIUM_UNFORMATTED))) {
 			/* media must have data/audio */
 			return BRASERO_BURN_NOT_SUPPORTED;
 		}
@@ -2328,11 +2410,12 @@ brasero_burn_caps_get_flags (BraseroBurnCaps *self,
 		supported_flags |= BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE;
 		compulsory_flags |= BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE;
 
-		/* pretends it is blank and see if it would work. If it works
-		 * then that means that the BLANK_BEFORE_WRITE flag is
-		 * compulsory. */
+		/* pretends it is blank and formatted to see if it would work.
+		 * If it works then that means that the BLANK_BEFORE_WRITE flag
+		 * is compulsory. */
 		media &= ~(BRASERO_MEDIUM_CLOSED|
 			   BRASERO_MEDIUM_APPENDABLE|
+			   BRASERO_MEDIUM_UNFORMATTED|
 			   BRASERO_MEDIUM_HAS_DATA|
 			   BRASERO_MEDIUM_HAS_AUDIO);
 		media |= BRASERO_MEDIUM_BLANK;
@@ -2946,7 +3029,22 @@ brasero_caps_disc_new_status (GSList *retval,
 	if ((type & BRASERO_MEDIUM_BLANK)
 	&& !(media & BRASERO_MEDIUM_ROM)) {
 		/* if media is blank there is no other possible property */
-		retval = brasero_caps_disc_lookup_or_create (retval, media|BRASERO_MEDIUM_BLANK);
+		if (BRASERO_MEDIUM_IS (type, BRASERO_MEDIUM_DVDRW_PLUS)
+		||  BRASERO_MEDIUM_IS (type, BRASERO_MEDIUM_DVDRW_RESTRICTED)
+		||  BRASERO_MEDIUM_IS (type, BRASERO_MEDIUM_DVDRW_PLUS_DL)) {
+			/* This is only for above types */
+			retval = brasero_caps_disc_lookup_or_create (retval,
+								     media|
+								     BRASERO_MEDIUM_BLANK);
+			retval = brasero_caps_disc_lookup_or_create (retval,
+								     media|
+								     BRASERO_MEDIUM_BLANK|
+								     (type & BRASERO_MEDIUM_UNFORMATTED));
+		}
+		else
+			retval = brasero_caps_disc_lookup_or_create (retval,
+								     media|
+								     BRASERO_MEDIUM_BLANK);
 	}
 
 	if (type & BRASERO_MEDIUM_CLOSED) {
