@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * brasero
- * Copyright (C) Philippe Rouquier 2007 <bonfire-app@wanadoo.fr>
+ * Copyright (C) Philippe Rouquier 2007-2008 <bonfire-app@wanadoo.fr>
  * 
  * brasero is free software.
  * 
@@ -141,6 +141,9 @@ brasero_medium_get_icon (BraseroMedium *medium)
 {
 	BraseroMediumPrivate *priv;
 
+	if (!medium)
+		return NULL;
+
 	priv = BRASERO_MEDIUM_PRIVATE (medium);
 	return priv->icon;
 }
@@ -624,9 +627,13 @@ brasero_medium_get_capacity_DVD_RW (BraseroMedium *self,
 		return BRASERO_BURN_ERR;
 	}
 
-	current = hdr->max_caps;
-
 	/* see if the media is already formatted */
+	current = hdr->max_caps;
+	if (!(current->type & BRASERO_SCSI_DESC_FORMATTED)) {
+		BRASERO_BURN_LOG ("Unformatted media");
+		priv->info |= BRASERO_MEDIUM_UNFORMATTED;
+	}
+
 	max = (hdr->len - 
 	      sizeof (BraseroScsiMaxCapacityDesc)) /
 	      sizeof (BraseroScsiFormattableCapacityDesc);
@@ -642,6 +649,7 @@ brasero_medium_get_capacity_DVD_RW (BraseroMedium *self,
 				/* that can happen */
 				if (!priv->block_size)
 					priv->block_size = 2048;
+
 				break;
 			}
 		}
@@ -1177,6 +1185,7 @@ brasero_medium_track_volume_size (BraseroMedium *self,
 				       &nb_blocks,
 				       NULL);
 	brasero_volume_source_close (vol);
+
 	if (!res) {
 		BRASERO_BURN_LOG ("Failed to retrieve the volume size: %s",
 				  error && error->message ? 
@@ -1881,7 +1890,10 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 				g_free (track);
 
 				priv->info |= BRASERO_MEDIUM_BLANK;
-				priv->info &= ~BRASERO_MEDIUM_CLOSED;
+				priv->info &= ~(BRASERO_MEDIUM_CLOSED|
+					        BRASERO_MEDIUM_HAS_DATA);
+
+				BRASERO_BURN_LOG ("Empty first session.");
 			}
 			else
 				priv->next_wr_add = 0;
@@ -1892,8 +1904,17 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 	priv->tracks = g_slist_reverse (priv->tracks);
 
 	if (BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_DVDRW_PLUS)
-	||  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_DVDRW_RESTRICTED))
-		brasero_medium_add_DVD_plus_RW_leadout (self, BRASERO_GET_32 (desc->track_start));
+	||  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_DVDRW_RESTRICTED)) {
+		gint32 start;
+
+		/* It starts where the other one finishes */
+		if (priv->tracks)
+			start = BRASERO_GET_32 (desc->track_start);
+		else
+			start = 0;
+
+		brasero_medium_add_DVD_plus_RW_leadout (self, start);
+	}
 	else if (!(priv->info & BRASERO_MEDIUM_CLOSED)) {
 		BraseroMediumTrack *track;
 
