@@ -33,11 +33,13 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#include <gio/gio.h>
+
 #include "burn-track.h"
 #include "burn-debug.h"
 #include "burn-medium.h"
 #include "burn-image-format.h"
-#include "brasero-ncb.h"
+#include "burn-drive.h"
 #include "burn-mkisofs-base.h"
 
 struct _BraseroTrack {
@@ -45,6 +47,8 @@ struct _BraseroTrack {
 
 	int ref;
 
+	GHashTable *tags;
+
 	gchar *checksum;
 	BraseroChecksumType checksum_type;
 };
@@ -59,7 +63,7 @@ typedef struct {
 
 typedef struct {
 	BraseroTrack track;
-	NautilusBurnDrive *disc;
+	BraseroDrive *disc;
 	guint num;
 } BraseroTrackDisc;
 
@@ -89,10 +93,6 @@ brasero_graft_point_free (BraseroGraftPt *graft)
 		g_free (graft->uri);
 
 	g_free (graft->path);
-
-	g_slist_foreach (graft->excluded, (GFunc) g_free, NULL);
-	g_slist_free (graft->excluded);
-
 	g_free (graft);
 }
 
@@ -100,8 +100,6 @@ BraseroGraftPt *
 brasero_graft_point_copy (BraseroGraftPt *graft)
 {
 	BraseroGraftPt *newgraft;
-	GSList *iter;
-	gchar *uri;
 
 	g_return_val_if_fail (graft != NULL, NULL);
 
@@ -110,13 +108,6 @@ brasero_graft_point_copy (BraseroGraftPt *graft)
 	if (graft->uri)
 		newgraft->uri = g_strdup (graft->uri);
 
-	for (iter = graft->excluded; iter; iter = iter->next) {
-		uri = iter->data;
-		newgraft->excluded = g_slist_prepend (newgraft->excluded,
-						      g_strdup (uri));
-	}
-
-	newgraft->excluded = g_slist_reverse (newgraft->excluded);
 	return newgraft;
 }
 
@@ -220,6 +211,11 @@ brasero_track_clean (BraseroTrack *track)
 {
 	g_return_if_fail (track != NULL);
 
+	if (track->tags) {
+		g_hash_table_destroy (track->tags);
+		track->tags = NULL;
+	}
+
 	if (track->type.type == BRASERO_TRACK_TYPE_AUDIO) {
 		BraseroTrackAudio *audio = (BraseroTrackAudio *) track;
 
@@ -239,11 +235,6 @@ brasero_track_clean (BraseroTrack *track)
 			if (graft->path)
 				g_free (graft->path);
 
-			if (graft->excluded) {
-				g_slist_foreach (graft->excluded, (GFunc) g_free, NULL);
-				g_slist_free (graft->excluded);
-			}
-
 			g_free (graft);
 		}
 		g_slist_free (data->grafts);
@@ -254,7 +245,8 @@ brasero_track_clean (BraseroTrack *track)
 	else if (track->type.type == BRASERO_TRACK_TYPE_DISC) {
 		BraseroTrackDisc *drive = (BraseroTrackDisc *) track;
 
-		nautilus_burn_drive_unref (drive->disc);
+		if (drive->disc)
+			g_object_unref (drive->disc);
 	}
 	else if (track->type.type == BRASERO_TRACK_TYPE_IMAGE) {
 		BraseroTrackImage *image = (BraseroTrackImage *) track;
@@ -334,7 +326,15 @@ brasero_track_get_type (BraseroTrack *track,
 		BraseroTrackDisc *disc;
 
 		disc = (BraseroTrackDisc *) track;
-		type->subtype.media = NCB_MEDIA_GET_STATUS (disc->disc);
+
+		if (disc->disc) {
+			BraseroMedium *medium;
+
+			medium = brasero_drive_get_medium (disc->disc);
+			type->subtype.media = brasero_medium_get_status (medium);
+		}
+		else
+			type->subtype.media = BRASERO_MEDIUM_NONE;
 	}
 
 	return track->type.type;
@@ -365,7 +365,7 @@ brasero_track_data_copy (BraseroTrackData *track, BraseroTrackData *copy)
 static void
 brasero_track_disc_copy (BraseroTrackDisc *track, BraseroTrackDisc *copy)
 {
-	nautilus_burn_drive_ref (track->disc);
+	g_object_ref (track->disc);
 	copy->disc = track->disc;
 }
 
@@ -423,7 +423,7 @@ brasero_track_copy (BraseroTrack *track)
 }
 
 BraseroBurnResult
-brasero_track_set_drive_source (BraseroTrack *track, NautilusBurnDrive *drive)
+brasero_track_set_drive_source (BraseroTrack *track, BraseroDrive *drive)
 {
 	BraseroTrackDisc *disc;
 
@@ -433,11 +433,13 @@ brasero_track_set_drive_source (BraseroTrack *track, NautilusBurnDrive *drive)
 	disc = (BraseroTrackDisc *) track;
 
 	if (disc->disc)
-		nautilus_burn_drive_unref (disc->disc);
+		g_object_unref (disc->disc);
 
-	nautilus_burn_drive_ref (drive);
 	disc->disc = drive;
 
+	if (drive)
+		g_object_ref (drive);
+
 	return BRASERO_BURN_OK;
 }
 
@@ -637,6 +639,7 @@ brasero_track_get_localpath (const gchar *uri)
 {
 	gchar *localpath;
 	gchar *realuri;
+	GFile *file;
 
 	if (!uri)
 		return NULL;
@@ -647,8 +650,11 @@ brasero_track_get_localpath (const gchar *uri)
 	if (strncmp (uri, "file://", 7))
 		return NULL;
 
-	realuri = gnome_vfs_make_uri_from_input (uri);
-	localpath = gnome_vfs_get_local_path_from_uri (realuri);
+	file = g_file_new_for_commandline_arg (uri);
+	realuri = g_file_get_uri (file);
+	g_object_unref (file);
+
+	localpath = g_filename_from_uri (realuri, NULL, NULL);
 	g_free (realuri);
 
 	return localpath;
@@ -657,13 +663,20 @@ brasero_track_get_localpath (const gchar *uri)
 static gchar *
 brasero_track_get_uri (const gchar *uri)
 {
+	gchar *uri_return;
+	GFile *file;
+
 	if (!uri)
 		return NULL;
 
 	if (uri [0] != '/')
 		return g_strdup (uri);
-		
-	return gnome_vfs_make_uri_from_input (uri);
+
+	file = g_file_new_for_commandline_arg (uri);
+	uri_return = g_file_get_uri (file);
+	g_object_unref (file);
+
+	return uri_return;
 }
 
 gchar *
@@ -772,6 +785,7 @@ brasero_track_get_data_paths (BraseroTrack *track,
 			      const gchar *grafts_path,
 			      const gchar *excluded_path,
 			      const gchar *emptydir,
+			      const gchar *videodir,
 			      GError **error)
 {
 	BraseroBurnResult result;
@@ -784,6 +798,7 @@ brasero_track_get_data_paths (BraseroTrack *track,
 	result = brasero_mkisofs_base_write_to_files (data->grafts,
 						      data->excluded,
 						      emptydir,
+						      videodir,
 						      grafts_path,
 						      excluded_path,
 						      error);
@@ -791,7 +806,7 @@ brasero_track_get_data_paths (BraseroTrack *track,
 	return result;
 }
 
-NautilusBurnDrive *
+BraseroDrive *
 brasero_track_get_drive_source (BraseroTrack *track)
 {
 	BraseroTrackDisc *drive;
@@ -804,6 +819,19 @@ brasero_track_get_drive_source (BraseroTrack *track)
 	return drive->disc;
 }
 
+BraseroMedium *
+brasero_track_get_medium_source (BraseroTrack *track)
+{
+	BraseroTrackDisc *drive;
+
+	if (track->type.type != BRASERO_TRACK_TYPE_DISC)
+		return NULL;
+
+	drive = (BraseroTrackDisc *) track;
+
+	return brasero_drive_get_medium (drive->disc);
+}
+
 gint
 brasero_track_get_drive_track (BraseroTrack *track)
 {
@@ -833,14 +861,17 @@ brasero_track_get_image_source (BraseroTrack *track, gboolean uri)
 	if (!image->image) {
 		gchar *complement;
 		gchar *retval;
+		gchar *toc;
 
 		if (!image->toc) {
 			BRASERO_BURN_LOG ("Image nor toc were set");
 			return NULL;
 		}
 
-		complement = brasero_image_format_get_complement (track->type.subtype.img_format, 
-								  image->toc);
+		toc = brasero_track_get_localpath (image->toc);
+		complement = brasero_image_format_get_complement (track->type.subtype.img_format, toc);
+		g_free (toc);
+
 		if (!complement) {
 			BRASERO_BURN_LOG ("No complement could be retrieved");
 			return NULL;
@@ -891,7 +922,9 @@ brasero_track_set_checksum (BraseroTrack *track,
 	BraseroBurnResult result = BRASERO_BURN_OK;
 
 	if (type == track->checksum_type
-	&&  type == BRASERO_CHECKSUM_MD5
+	&& (type == BRASERO_CHECKSUM_MD5
+	||  type == BRASERO_CHECKSUM_SHA1
+	||  type == BRASERO_CHECKSUM_SHA256)
 	&&  strcmp (checksum, track->checksum))
 		result = BRASERO_BURN_ERR;
 
@@ -928,13 +961,15 @@ brasero_track_get_disc_capacity (BraseroTrack *track,
 				 gint64 *blocks,
 				 gint64 *size)
 {
-	NautilusBurnDrive *drive;
+	BraseroDrive *drive;
+	BraseroMedium *medium;
 
 	drive = brasero_track_get_drive_source (track);
 	if (!drive)
 		return BRASERO_BURN_ERR;
 
-	NCB_MEDIA_GET_CAPACITY (drive, size, blocks);
+	medium = brasero_drive_get_medium (drive);
+	brasero_medium_get_capacity (medium, size, blocks);
 	return BRASERO_BURN_OK;
 }
 
@@ -943,13 +978,15 @@ brasero_track_get_disc_data_size (BraseroTrack *track,
 				  gint64 *blocks,
 				  gint64 *size)
 {
-	NautilusBurnDrive *drive;
+	BraseroDrive *drive;
+	BraseroMedium *medium;
 
 	drive = brasero_track_get_drive_source (track);
 	if (!drive)
 		return BRASERO_BURN_ERR;
 
-	NCB_MEDIA_GET_DATA_SIZE (drive, size, blocks);
+	medium = brasero_drive_get_medium (drive);
+	brasero_medium_get_data_size (medium, size, blocks);
 	return BRASERO_BURN_OK;
 }
 
@@ -958,13 +995,15 @@ brasero_track_get_disc_free_space (BraseroTrack *track,
 				   gint64 *blocks,
 				   gint64 *size)
 {
-	NautilusBurnDrive *drive;
+	BraseroDrive *drive;
+	BraseroMedium *medium;
 
 	drive = brasero_track_get_drive_source (track);
 	if (!drive)
 		return BRASERO_BURN_ERR;
 
-	NCB_MEDIA_GET_FREE_SPACE (drive, size, blocks);
+	medium = brasero_drive_get_medium (drive);
+	brasero_medium_get_free_space (medium, size, blocks);
 	return BRASERO_BURN_OK;
 }
 
@@ -1085,3 +1124,50 @@ brasero_track_get_audio_length (BraseroTrack *track,
 
 	return BRASERO_BURN_OK;
 }
+
+/**
+ * Can be used to set arbitrary data
+ */
+static void
+brasero_track_tag_value_free (gpointer user_data)
+{
+	GValue *value = user_data;
+
+	g_value_reset (value);
+	g_free (value);
+}
+
+BraseroBurnResult
+brasero_track_tag_add (BraseroTrack *track,
+		       const gchar *tag,
+		       GValue *value)
+{
+	if (!track->tags)
+		track->tags = g_hash_table_new_full (g_str_hash,
+						     g_str_equal,
+						     g_free,
+						     brasero_track_tag_value_free);
+	g_hash_table_insert (track->tags, g_strdup (tag), value);
+	return BRASERO_BURN_OK;
+}
+
+BraseroBurnResult
+brasero_track_tag_lookup (BraseroTrack *track,
+			  const gchar *tag,
+			  GValue **value)
+{
+	gpointer data;
+
+	if (!track->tags)
+		return BRASERO_BURN_ERR;
+
+	data = g_hash_table_lookup (track->tags, tag);
+	if (!data)
+		return BRASERO_BURN_ERR;
+
+	if (value)
+		*value = data;
+
+	return BRASERO_BURN_OK;
+}
+
